@@ -14,6 +14,15 @@
 # limitations under the License.
 
 
+# CAM签名/鉴权错误。
+AUTHFAILURE = 'AuthFailure'
+
+# 操作失败。
+FAILEDOPERATION = 'FailedOperation'
+
+# 交易失败。
+FAILEDOPERATION_TRADEFAILED = 'FailedOperation.TradeFailed'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
@@ -89,6 +98,9 @@ INVALIDPARAMETER_ERRNAMESPACERESERVED = 'InvalidParameter.ErrNamespaceReserved'
 # 无效的参数，仓库已存在。
 INVALIDPARAMETER_ERRREPOEXIST = 'InvalidParameter.ErrRepoExist'
 
+# 请求参数数量过多。
+INVALIDPARAMETER_ERRREQARGSTOOLARGE = 'InvalidParameter.ErrReqArgsTooLarge'
+
 # 触发器名称已存在。
 INVALIDPARAMETER_ERRTRIGGEREXIST = 'InvalidParameter.ErrTriggerExist'
 
